searchData={"content_type":"text/markdown","items":[{"doc":"Nested provides functions to access nested data in map and list with ease","ref":"Nested.html","title":"Nested","type":"module"},{"doc":"Replace value in map and list with  `***` if key match any of keywords\n\n**Examples**\n\n    data = %{users:\n      [\n        %{name: \"user1\", is_active: true, skills: [\"js\", \"html\"]},\n        %{name: \"user2\", is_active: false, skills: [\"elixir\", \"sql\"]}]\n      }\n\n    Nested.censor(data, [\"active\", \"skills\"])\n\n    #> %{users:\n      [\n        %{name: \"user1\", is_active: \"***\", skills: \"***\"},\n        %{name: \"user2\", is_active: \"***\", skills: \"***\"}]\n      }","ref":"Nested.html#censor/2","title":"Nested.censor/2","type":"function"},{"doc":"Clean nil value in map and list","ref":"Nested.html#clean_nil/1","title":"Nested.clean_nil/1","type":"function"},{"doc":"Query data nested in map and list\n\n**Params**:\n- `object`: map or list\n- `paths`: list of key or index, or function to compare\n  + `*` match all\n  + `integer` match index or map key\n  + `atom` match keyword key or map key\n  + `map` match map item in list\n  + `function` match list item with function\n  + `string` match map string key\n\n**Example**\n\n    data = %{users:\n      [\n        %{name: \"user1\", is_active: true, skills: [\"js\", \"html\"]},\n        %{name: \"user2\", is_active: false, skills: [\"elixir\", \"sql\"]}]\n      }\n\n    Nested.extract(data, [:users, \"*\", :skills ])\n\n    #> [[\"js\", \"html\"], [\"elixir\", \"sql\"]]","ref":"Nested.html#extract/2","title":"Nested.extract/2","type":"function"},{"doc":"Query data nested in map and list\nReturn: `{:ok, data}` if found and `:error` if not found\n\nIt support compare condition for list item which is a map\n\n**Example**\n\n    data = %{users:\n      [\n        %{name: \"user1\", is_active: true, skills: [\"js\", \"html\"]},\n        %{name: \"user2\", is_active: false, skills: [\"elixir\", \"sql\"]}]\n      }\n\n    Nested.fetch(data, [:users, %{is_active: true}, :skills ])\n\n    #> {:ok, [\"js\", \"html\"]}","ref":"Nested.html#fetch/2","title":"Nested.fetch/2","type":"function"},{"doc":"Query data nested in map and list, return default if path not exist\n\nExample:\n\nget(%{a: 1, b: [%{name: \"test1\"}, %{name: \"test\"2}]}, [:b, 0, :name])\n#> \"test1\"","ref":"Nested.html#get/3","title":"Nested.get/3","type":"function"},{"doc":"Merge two maps deeply, preferring values from the right map.","ref":"Nested.html#merge/2","title":"Nested.merge/2","type":"function"},{"doc":"Convert struct to map by removing `__struct__` and `__meta__` keys","ref":"Nested.html#to_map/1","title":"Nested.to_map/1","type":"function"},{"doc":"Traverse map and list, apply function to each item\n\n**Params**:\n- `object`: map or list\n- `fun/1`: function to apply to each item of map or list and return one of:\n  + `:discard`: discard item\n  + `{:skip, item}`: skip traverse nested value\n  + `{:next, item}`: traverse nested value\n  + `item`: behavior as `{:next, item}`\n\n**Examples**:\n      # remove all `is_active` key\n      data = %{users:\n        [\n          %{name: \"user1\", is_active: true, skills: [\"js\", \"html\"]},\n          %{name: \"user2\", is_active: false, skills: [\"elixir\", \"sql\"]}]\n        }\n\n      Nested.traverse(data, fn\n        {:is_active, _} -> :discard\n        item -> IO.inspect(item)\n      end)\n\n      #> %{users:\n        [\n          %{name: \"user1\", skills: [\"js\", \"html\"]},\n          %{name: \"user2\", skills: [\"elixir\", \"sql\"]}]\n        }","ref":"Nested.html#traverse/2","title":"Nested.traverse/2","type":"function"},{"doc":"# Nested\n\n**TODO: Add description**","ref":"readme.html","title":"Nested","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `nested` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nested, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation","title":"Installation - Nested","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}